## How to use the notebooks in this folder

This folder contains Jupyter notebooks that interact with `timelink`.

In order to use the notebooks you need to install VSCode, the Python interpreter and support libraries.

1. Install VSCode from https://code.visualstudio.com/download
2. Install the Python VSCode extension from  https://marketplace.visualstudio.com/items?itemName=ms-python.python
3. After restarting VS Code and set up your environment as instructed in step 2, install the support libraries:
    * Open a terminal in the  menu `Terminal` -> `New terminal`
    * Type ``pip install -r notebooks/requirements.txt`` or if, you are on a windows terminal
         ``pip install -r notebooks\requirements.txt``
4. Install Docker. See https://docs.docker.com/get-docker/

See the notebook [0.tutorial](tests/timelink-home/projects/test-project/notebooks/0.tutorial.ipynb) for a tutorial on how to use `timelink` in a notebook.

If you have problems create an issue or start a discussion in https://github.com/time-link/timelink-py

